==> iam-2.10.56-sources.jar: software/amazon/awssdk/services/iam/paginators/GetAccountAuthorizationDetailsIterable.java <==
/*
 * Copyright 2015-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.iam.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.services.iam.IamClient;
import software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsRequest;
import software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsResponse;
import software.amazon.awssdk.services.iam.model.GroupDetail;
import software.amazon.awssdk.services.iam.model.ManagedPolicyDetail;
import software.amazon.awssdk.services.iam.model.RoleDetail;
import software.amazon.awssdk.services.iam.model.UserDetail;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.iam.IamClient#getAccountAuthorizationDetailsPaginator(software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iam.paginators.GetAccountAuthorizationDetailsIterable responses = client.getAccountAuthorizationDetailsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.iam.paginators.GetAccountAuthorizationDetailsIterable responses = client
 *             .getAccountAuthorizationDetailsPaginator(request);
 *     for (software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iam.paginators.GetAccountAuthorizationDetailsIterable responses = client.getAccountAuthorizationDetailsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #getAccountAuthorizationDetails(software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class GetAccountAuthorizationDetailsIterable implements SdkIterable<GetAccountAuthorizationDetailsResponse> {
    private final IamClient client;

    private final GetAccountAuthorizationDetailsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public GetAccountAuthorizationDetailsIterable(IamClient client, GetAccountAuthorizationDetailsRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new GetAccountAuthorizationDetailsResponseFetcher();
    }

    @Override
    public Iterator<GetAccountAuthorizationDetailsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link GetAccountAuthorizationDetailsResponse#userDetailList()} member. The returned iterable is used to iterate
     * through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<UserDetail> userDetailList() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<UserDetail>> getIterator = response -> {
            if (response != null && response.userDetailList() != null) {
                return response.userDetailList().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.builder().pagesIterable(this).itemIteratorFunction(getIterator).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link GetAccountAuthorizationDetailsResponse#groupDetailList()} member. The returned iterable is used to iterate
     * through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<GroupDetail> groupDetailList() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<GroupDetail>> getIterator = response -> {
            if (response != null && response.groupDetailList() != null) {
                return response.groupDetailList().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.builder().pagesIterable(this).itemIteratorFunction(getIterator).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link GetAccountAuthorizationDetailsResponse#roleDetailList()} member. The returned iterable is used to iterate
     * through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<RoleDetail> roleDetailList() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<RoleDetail>> getIterator = response -> {
            if (response != null && response.roleDetailList() != null) {
                return response.roleDetailList().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.builder().pagesIterable(this).itemIteratorFunction(getIterator).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link GetAccountAuthorizationDetailsResponse#policies()}
     * member. The returned iterable is used to iterate through the results across all response pages and not a single
     * page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<ManagedPolicyDetail> policies() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<ManagedPolicyDetail>> getIterator = response -> {
            if (response != null && response.policies() != null) {
                return response.policies().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.builder().pagesIterable(this).itemIteratorFunction(getIterator).build();
    }

    private class GetAccountAuthorizationDetailsResponseFetcher implements
            SyncPageFetcher<GetAccountAuthorizationDetailsResponse> {
        @Override
        public boolean hasNextPage(GetAccountAuthorizationDetailsResponse previousPage) {
            return previousPage.isTruncated().booleanValue();
        }

        @Override
        public GetAccountAuthorizationDetailsResponse nextPage(GetAccountAuthorizationDetailsResponse previousPage) {
            if (previousPage == null) {
                return client.getAccountAuthorizationDetails(firstRequest);
            }
            return client.getAccountAuthorizationDetails(firstRequest.toBuilder().marker(previousPage.marker()).build());
        }
    }
}

==> iam-2.11.6-sources.jar: software/amazon/awssdk/services/iam/paginators/GetAccountAuthorizationDetailsIterable.java <==
/*
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance with
 * the License. A copy of the License is located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
 * CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */

package software.amazon.awssdk.services.iam.paginators;

import java.util.Collections;
import java.util.Iterator;
import java.util.function.Function;
import software.amazon.awssdk.annotations.Generated;
import software.amazon.awssdk.core.pagination.sync.PaginatedItemsIterable;
import software.amazon.awssdk.core.pagination.sync.PaginatedResponsesIterator;
import software.amazon.awssdk.core.pagination.sync.SdkIterable;
import software.amazon.awssdk.core.pagination.sync.SyncPageFetcher;
import software.amazon.awssdk.services.iam.IamClient;
import software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsRequest;
import software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsResponse;
import software.amazon.awssdk.services.iam.model.GroupDetail;
import software.amazon.awssdk.services.iam.model.ManagedPolicyDetail;
import software.amazon.awssdk.services.iam.model.RoleDetail;
import software.amazon.awssdk.services.iam.model.UserDetail;

/**
 * <p>
 * Represents the output for the
 * {@link software.amazon.awssdk.services.iam.IamClient#getAccountAuthorizationDetailsPaginator(software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsRequest)}
 * operation which is a paginated operation. This class is an iterable of
 * {@link software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsResponse} that can be used to iterate
 * through all the response pages of the operation.
 * </p>
 * <p>
 * When the operation is called, an instance of this class is returned. At this point, no service calls are made yet and
 * so there is no guarantee that the request is valid. As you iterate through the iterable, SDK will start lazily
 * loading response pages by making service calls until there are no pages left or your iteration stops. If there are
 * errors in your request, you will see the failures only after you start iterating through the iterable.
 * </p>
 *
 * <p>
 * The following are few ways to iterate through the response pages:
 * </p>
 * 1) Using a Stream
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iam.paginators.GetAccountAuthorizationDetailsIterable responses = client.getAccountAuthorizationDetailsPaginator(request);
 * responses.stream().forEach(....);
 * }
 * </pre>
 *
 * 2) Using For loop
 * 
 * <pre>
 * {
 *     &#064;code
 *     software.amazon.awssdk.services.iam.paginators.GetAccountAuthorizationDetailsIterable responses = client
 *             .getAccountAuthorizationDetailsPaginator(request);
 *     for (software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsResponse response : responses) {
 *         // do something;
 *     }
 * }
 * </pre>
 *
 * 3) Use iterator directly
 * 
 * <pre>
 * {@code
 * software.amazon.awssdk.services.iam.paginators.GetAccountAuthorizationDetailsIterable responses = client.getAccountAuthorizationDetailsPaginator(request);
 * responses.iterator().forEachRemaining(....);
 * }
 * </pre>
 * <p>
 * <b>Note: If you prefer to have control on service calls, use the
 * {@link #getAccountAuthorizationDetails(software.amazon.awssdk.services.iam.model.GetAccountAuthorizationDetailsRequest)}
 * operation.</b>
 * </p>
 */
@Generated("software.amazon.awssdk:codegen")
public class GetAccountAuthorizationDetailsIterable implements SdkIterable<GetAccountAuthorizationDetailsResponse> {
    private final IamClient client;

    private final GetAccountAuthorizationDetailsRequest firstRequest;

    private final SyncPageFetcher nextPageFetcher;

    public GetAccountAuthorizationDetailsIterable(IamClient client, GetAccountAuthorizationDetailsRequest firstRequest) {
        this.client = client;
        this.firstRequest = firstRequest;
        this.nextPageFetcher = new GetAccountAuthorizationDetailsResponseFetcher();
    }

    @Override
    public Iterator<GetAccountAuthorizationDetailsResponse> iterator() {
        return PaginatedResponsesIterator.builder().nextPageFetcher(nextPageFetcher).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link GetAccountAuthorizationDetailsResponse#userDetailList()} member. The returned iterable is used to iterate
     * through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<UserDetail> userDetailList() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<UserDetail>> getIterator = response -> {
            if (response != null && response.userDetailList() != null) {
                return response.userDetailList().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<GetAccountAuthorizationDetailsResponse, UserDetail> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link GetAccountAuthorizationDetailsResponse#groupDetailList()} member. The returned iterable is used to iterate
     * through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<GroupDetail> groupDetailList() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<GroupDetail>> getIterator = response -> {
            if (response != null && response.groupDetailList() != null) {
                return response.groupDetailList().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<GetAccountAuthorizationDetailsResponse, GroupDetail> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    /**
     * Returns an iterable to iterate through the paginated
     * {@link GetAccountAuthorizationDetailsResponse#roleDetailList()} member. The returned iterable is used to iterate
     * through the results across all response pages and not a single page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<RoleDetail> roleDetailList() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<RoleDetail>> getIterator = response -> {
            if (response != null && response.roleDetailList() != null) {
                return response.roleDetailList().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<GetAccountAuthorizationDetailsResponse, RoleDetail> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    /**
     * Returns an iterable to iterate through the paginated {@link GetAccountAuthorizationDetailsResponse#policies()}
     * member. The returned iterable is used to iterate through the results across all response pages and not a single
     * page.
     *
     * This method is useful if you are interested in iterating over the paginated member in the response pages instead
     * of the top level pages. Similar to iteration over pages, this method internally makes service calls to get the
     * next list of results until the iteration stops or there are no more results.
     */
    public final SdkIterable<ManagedPolicyDetail> policies() {
        Function<GetAccountAuthorizationDetailsResponse, Iterator<ManagedPolicyDetail>> getIterator = response -> {
            if (response != null && response.policies() != null) {
                return response.policies().iterator();
            }
            return Collections.emptyIterator();
        };
        return PaginatedItemsIterable.<GetAccountAuthorizationDetailsResponse, ManagedPolicyDetail> builder().pagesIterable(this)
                .itemIteratorFunction(getIterator).build();
    }

    private class GetAccountAuthorizationDetailsResponseFetcher implements
            SyncPageFetcher<GetAccountAuthorizationDetailsResponse> {
        @Override
        public boolean hasNextPage(GetAccountAuthorizationDetailsResponse previousPage) {
            return previousPage.isTruncated().booleanValue();
        }

        @Override
        public GetAccountAuthorizationDetailsResponse nextPage(GetAccountAuthorizationDetailsResponse previousPage) {
            if (previousPage == null) {
                return client.getAccountAuthorizationDetails(firstRequest);
            }
            return client.getAccountAuthorizationDetails(firstRequest.toBuilder().marker(previousPage.marker()).build());
        }
    }
}
